@@ -6,7 +6,9 @@ import groq
 import httpx
 import openai
 
-from maitai._config import config
+from maitai._config import Config
+from maitai._context import ContextManager
+from maitai.agent._completions import Completions as AgentCompletions
 from maitai.chat._completions import Completions
 from maitai.models.chat import AzureParams, ClientParams
 from maitai.models.key import Key
@@ -46,9 +48,7 @@ class Maitai:
     ):
         if not maitai_api_key:
             maitai_api_key = os.environ.get("MAITAI_API_KEY")
-        if maitai_api_key:
-            config.initialize(maitai_api_key)
-        else:
+        if not maitai_api_key:
             raise ValueError(
                 "MAITAI_API_KEY has not been set. Either set via environment variable or pass it directly into the client."
             )
@@ -56,62 +56,63 @@ class Maitai:
             raise ValueError(
                 "api_key is deprecated. Use provider specific keys instead. Supported variables: openai_api_key, groq_api_key, anthropic_api_key, cerebras_api_key, azure_api_key, sambanova_api_key, gemini_api_key, deepseek_api_key"
             )
+        self.config = Config(maitai_api_key)
         if openai_api_key:
-            if not config.auth_keys.openai_api_key:
-                config.auth_keys.openai_api_key = Key(
+            if not self.config.auth_keys.openai_api_key:
+                self.config.auth_keys.openai_api_key = Key(
                     key_value=openai_api_key,
                 )
             else:
-                config.auth_keys.openai_api_key.key_value = openai_api_key
+                self.config.auth_keys.openai_api_key.key_value = openai_api_key
         if groq_api_key:
-            if not config.auth_keys.groq_api_key:
-                config.auth_keys.groq_api_key = Key(
+            if not self.config.auth_keys.groq_api_key:
+                self.config.auth_keys.groq_api_key = Key(
                     key_value=groq_api_key,
                 )
             else:
-                config.auth_keys.groq_api_key.key_value = groq_api_key
+                self.config.auth_keys.groq_api_key.key_value = groq_api_key
         if anthropic_api_key:
-            if not config.auth_keys.anthropic_api_key:
-                config.auth_keys.anthropic_api_key = Key(
+            if not self.config.auth_keys.anthropic_api_key:
+                self.config.auth_keys.anthropic_api_key = Key(
                     key_value=anthropic_api_key,
                 )
             else:
-                config.auth_keys.anthropic_api_key.key_value = anthropic_api_key
+                self.config.auth_keys.anthropic_api_key.key_value = anthropic_api_key
         if cerebras_api_key:
-            if not config.auth_keys.cerebras_api_key:
-                config.auth_keys.cerebras_api_key = Key(
+            if not self.config.auth_keys.cerebras_api_key:
+                self.config.auth_keys.cerebras_api_key = Key(
                     key_value=cerebras_api_key,
                 )
             else:
-                config.auth_keys.cerebras_api_key.key_value = cerebras_api_key
+                self.config.auth_keys.cerebras_api_key.key_value = cerebras_api_key
         if azure_api_key:
-            if not config.auth_keys.azure_api_key:
-                config.auth_keys.azure_api_key = Key(
+            if not self.config.auth_keys.azure_api_key:
+                self.config.auth_keys.azure_api_key = Key(
                     key_value=azure_api_key,
                 )
             else:
-                config.auth_keys.azure_api_key.key_value = azure_api_key
+                self.config.auth_keys.azure_api_key.key_value = azure_api_key
         if sambanova_api_key:
-            if not config.auth_keys.sambanova_api_key:
-                config.auth_keys.sambanova_api_key = Key(
+            if not self.config.auth_keys.sambanova_api_key:
+                self.config.auth_keys.sambanova_api_key = Key(
                     key_value=sambanova_api_key,
                 )
             else:
-                config.auth_keys.sambanova_api_key.key_value = sambanova_api_key
+                self.config.auth_keys.sambanova_api_key.key_value = sambanova_api_key
         if gemini_api_key:
-            if not config.auth_keys.gemini_api_key:
-                config.auth_keys.gemini_api_key = Key(
+            if not self.config.auth_keys.gemini_api_key:
+                self.config.auth_keys.gemini_api_key = Key(
                     key_value=gemini_api_key,
                 )
             else:
-                config.auth_keys.gemini_api_key.key_value = gemini_api_key
+                self.config.auth_keys.gemini_api_key.key_value = gemini_api_key
         if deepseek_api_key:
-            if not config.auth_keys.deepseek_api_key:
-                config.auth_keys.deepseek_api_key = Key(
+            if not self.config.auth_keys.deepseek_api_key:
+                self.config.auth_keys.deepseek_api_key = Key(
                     key_value=deepseek_api_key,
                 )
             else:
-                config.auth_keys.deepseek_api_key.key_value = deepseek_api_key
+                self.config.auth_keys.deepseek_api_key.key_value = deepseek_api_key
         self._openai_client = None
         self._groq_client = None
         azure_params = None
@@ -149,16 +150,13 @@ class Maitai:
                 http_client=http_client,
                 _strict_response_validation=_strict_response_validation,
             )
-        if groq_api_key or config.auth_keys.groq_api_key:
-
-            self._groq_client = groq.Groq(
-                api_key=groq_api_key
-                or (
-                    config.auth_keys.groq_api_key.key_value
-                    if config.auth_keys.groq_api_key
-                    else None
-                ),
-            )
+        groq_key_value = groq_api_key or (
+            self.config.auth_keys.groq_api_key.key_value
+            if self.config.auth_keys.groq_api_key
+            else None
+        )
+        if groq_key_value and groq_key_value.strip():
+            self._groq_client = groq.Groq(api_key=groq_key_value)
 
         client_params = None
         if base_url or default_headers or default_query:
@@ -172,25 +170,38 @@ class Maitai:
             if azure_params:
                 client_param_dict["azure_params"] = azure_params
             client_params = ClientParams(**client_param_dict)
-        self.chat = Chat(self._openai_client, self._groq_client, client_params)
-        self.audio = Audio(self._openai_client, self._groq_client, client_params)
+        self.chat = Chat(
+            self.config, self._openai_client, self._groq_client, client_params
+        )
+        self.audio = Audio(self.config)
+        self.agent = Agent(self.config)
+        self.context = ContextManager(self.config)
 
 
 class Chat:
     def __init__(
         self,
-        openai_client=None,
-        groq_client=None,
+        config: Config,
+        openai_client: Optional[openai.Client] = None,
+        groq_client: Optional[groq.Groq] = None,
         client_params: Optional[ClientParams] = None,
     ):
-        self.completions = Completions(openai_client, groq_client, client_params)
+        self.completions = Completions(
+            config, openai_client, groq_client, client_params
+        )
 
 
 class Audio:
     def __init__(
         self,
-        openai_client=None,
-        groq_client=None,
-        client_params: Optional[ClientParams] = None,
+        config: Config,
     ):
-        self.transcriptions = Transcriptions(openai_client)
+        self.transcriptions = Transcriptions(config)
+
+
+class Agent:
+    def __init__(
+        self,
+        config: Config,
+    ):
+        self.completions = AgentCompletions(config)
