@@ -5,6 +5,14 @@ import httpx
 
 from maitai_common.version import version
 
+try:
+    from opentelemetry import trace
+
+    from maitai_back.instrumentation.tracer import trace_span, tracer
+except ImportError:
+    tracer = None
+    trace = None
+
 # Common client settings to ensure consistency
 CLIENT_SETTINGS = {
     "http2": True,
@@ -65,8 +73,37 @@ class MaitaiClient:
 
     def __init__(self):
         self.executor = concurrent.futures.ThreadPoolExecutor()
+        self.maitai_transcription_host = self._determine_maitai_transcription_host()
+        self.maitai_orchestration_host = self._determine_maitai_orchestration_host()
+        self.maitai_inference_host = self._determine_maitai_inference_host()
+
+    def _determine_maitai_transcription_host(self):
+        if maitai_transcription_host := os.environ.get(
+            "MAITAI_TRANSCRIPTION_SERVICE_URL"
+        ):
+            return maitai_transcription_host.rstrip("/")
+        return self.maitai_host
+
+    def _determine_maitai_orchestration_host(self):
+        if maitai_agent_host := os.environ.get("MAITAI_AGENT_HOST"):
+            maitai_agent_host = maitai_agent_host.rstrip("/")
+            if maitai_agent_host.endswith("/agent"):
+                maitai_agent_host = maitai_agent_host[: -len("/agent")]
+            return maitai_agent_host.rstrip("/")
+        return self.maitai_host
+
+    def _determine_maitai_inference_host(self):
+        if maitai_inference_host := os.environ.get("MAITAI_INFERENCE_HOST"):
+            return maitai_inference_host.rstrip("/")
+        return self.maitai_host
 
     def get_client(self):
+        if tracer:
+            with tracer.start_as_current_span("get_client"):
+                return self._get_client()
+        return self._get_client()
+
+    def _get_client(self):
         if self._client is None:
             self._client = httpx.Client(
                 **CLIENT_SETTINGS,
@@ -74,15 +111,32 @@ class MaitaiClient:
             )
         return self._client
 
-    async def get_async_client(self):
-        if self._async_client is None:
-            self._async_client = httpx.AsyncClient(
-                **CLIENT_SETTINGS,
-                transport=httpx.AsyncHTTPTransport(
-                    retries=DEFAULT_MAX_RETRIES, http2=True
-                ),
-            )
-        return self._async_client
+    def get_async_client(self):
+        if tracer:
+            with tracer.start_as_current_span("get_async_client"):
+                return self._get_async_client()
+        return self._get_async_client()
+
+    def _get_async_client(self):
+        if tracer:
+            with tracer.start_as_current_span("create_async_client"):
+                if self._async_client is None:
+                    self._async_client = httpx.AsyncClient(
+                        **CLIENT_SETTINGS,
+                        transport=httpx.AsyncHTTPTransport(
+                            retries=DEFAULT_MAX_RETRIES, http2=True
+                        ),
+                    )
+                return self._async_client
+        else:
+            if self._async_client is None:
+                self._async_client = httpx.AsyncClient(
+                    **CLIENT_SETTINGS,
+                    transport=httpx.AsyncHTTPTransport(
+                        retries=DEFAULT_MAX_RETRIES, http2=True
+                    ),
+                )
+            return self._async_client
 
     def cleanup(self):
         try:
@@ -147,12 +201,18 @@ class MaitaiClient:
             "path": path,
         }
         try:
-            client = await self.get_async_client()
+            client = self.get_async_client()
             return await client.put(url, headers=headers, json=labels)
         except:
             pass
 
     def init_sdk(self, api_key: str, host: str):
+        if tracer:
+            with tracer.start_as_current_span("init_sdk"):
+                return self._init_sdk(api_key, host)
+        return self._init_sdk(api_key, host)
+
+    def _init_sdk(self, api_key: str, host: str):
         """Initialize the SDK and warm up connections."""
         if "/batch" in host:
             host = host.replace("/batch", "")
