@@ -1,4 +1,5 @@
 import logging
+import os
 import time
 import uuid
 import warnings
@@ -10,7 +11,7 @@ import openai
 import openai.types as openai_types
 import openai.types.chat as openai_chat_types
 
-from maitai._config import config
+from maitai._config import Config
 from maitai._evaluator import Evaluator
 from maitai._inference import Inference
 from maitai._types import (
@@ -50,6 +51,7 @@ DEFAULT_MAX_RETRIES = 2
 class Completions:
     def __init__(
         self,
+        config: Config,
         openai_client: Optional[openai.Client] = None,
         groq_client: Optional[groq.Groq] = None,
         client_params: Optional[ClientParams] = None,
@@ -57,8 +59,12 @@ class Completions:
         self._openai_client = openai_client
         self._groq_client = groq_client
         self._client_params = client_params or ClientParams()
-        self.evaluator = Evaluator()
-        self.inference = Inference()
+        self.evaluator = Evaluator(config)
+        self.inference = Inference(config)
+        self.config = config
+        self.override_push_timing_metrics = os.environ.get(
+            "MAITAI_DONT_PUSH_TIMING_METRICS"
+        )
 
     @required_args(
         ["intent", "application", "messages"],
@@ -85,6 +91,7 @@ class Completions:
         safe_mode: Optional[bool] = None,
         fallback_config: Union[FallbackConfig, dict, None] = None,
         return_request: bool = False,
+        push_timing_metrics: bool = True,
         # OpenAI Arguments
         messages: Iterable[openai_chat_types.ChatCompletionMessageParam],
         model: Union[str, openai_types.ChatModel, openai.NotGiven] = openai.NOT_GIVEN,
@@ -139,7 +146,10 @@ class Completions:
         timing = RequestTimingMetric(
             time_request_start=time.time(),
         )
-        if not config.api_key:
+        # Check environment variable to override push_timing_metrics default
+        if self.override_push_timing_metrics:
+            push_timing_metrics = False
+        if not self.config.api_key:
             raise ValueError("Maitai API Key has not been set")
         if server_side_inference is False and apply_corrections is True:
             raise ValueError("server_side_inference must be true to apply_corrections")
@@ -147,7 +157,7 @@ class Completions:
             raise ValueError("evaluations must be enabled to apply_corrections")
         if not session_id:
             session_id = str(uuid.uuid4())
-        maitai_config = config.get_application_action_config(application, intent)
+        maitai_config = self.config.get_application_action_config(application, intent)
         if server_side_inference is None:
             server_side_inference = (
                 maitai_config.inference_location == InferenceLocations.SERVER
@@ -226,7 +236,7 @@ class Completions:
                 "params": completion_params,
                 "return_evaluation": True if callback else False,
                 "user_id": user_id,
-                "auth_keys": config.auth_keys.model_dump(),
+                "auth_keys": self.config.auth_keys.model_dump(),
                 "metadata": metadata,
                 "safe_mode": safe_mode,
                 "return_request": return_request,
@@ -255,6 +265,7 @@ class Completions:
                             if stream_options and stream_options != openai.NOT_GIVEN
                             else False
                         ),
+                        push_timing_metrics=push_timing_metrics,
                     )
                 # ChatCompletion only
                 for resp in response:
@@ -266,7 +277,8 @@ class Completions:
                         raise InferenceException(resp.error)
                     timing.request_id = resp.chat_completion_response.request_id
                     timing.time_request_end = time.time()
-                    self.inference.store_request_timing_data(timing)
+                    if push_timing_metrics:
+                        self.inference.store_request_timing_data(timing)
                     completion = MaitaiCompletion.model_validate(
                         resp.chat_completion_response.model_dump()
                     )
@@ -325,22 +337,22 @@ class Completions:
             if groq_model:
                 if self._groq_client is None:
                     if (
-                        not config.auth_keys.groq_api_key
-                        or not config.auth_keys.groq_api_key.key_value
+                        not self.config.auth_keys.groq_api_key
+                        or not self.config.auth_keys.groq_api_key.key_value
                     ):
                         raise ValueError(
                             "Groq API key is required for Groq models but was not provided"
                         )
 
                     self._groq_client = groq.Groq(
-                        api_key=config.auth_keys.groq_api_key.key_value,
+                        api_key=self.config.auth_keys.groq_api_key.key_value,
                     )
                 client_to_use = self._groq_client
                 local_params = convert_params_to_groq(local_params)
             else:
                 if self._openai_client is None:
                     self._openai_client = openai.OpenAI(
-                        api_key=config.auth_keys.openai_api_key.key_value,
+                        api_key=self.config.auth_keys.openai_api_key.key_value,
                         default_headers=self._client_params.default_headers or None,
                         default_query=self._client_params.default_query or None,
                         base_url=self._client_params.base_url or None,
@@ -478,6 +490,7 @@ class Completions:
         retry_args: dict,
         timing: RequestTimingMetric,
         includes_usage: bool = False,
+        push_timing_metrics: bool = True,
     ) -> Iterable[MaitaiChunk]:
         first = True
         try:
@@ -495,7 +508,8 @@ class Completions:
                     yield MaitaiChunk.model_validate(chunk.model_dump())
                     if chunk.choices and chunk.choices[0].finish_reason:
                         timing.time_request_end = time.time()
-                        self.inference.store_request_timing_data(timing)
+                        if push_timing_metrics:
+                            self.inference.store_request_timing_data(timing)
                     if chunk.choices and chunk.choices[0].finish_reason:
                         return
         except MaitaiConnectionError as e:
