@@ -1,4 +1,6 @@
 # codegen: frontend, sdk
+from __future__ import annotations
+
 from typing import Any, Dict, List, Optional, Union
 
 from pydantic import BaseModel, Field
@@ -8,7 +10,7 @@ from maitai.models.config import Config
 
 class ApplicationObjective(BaseModel):
     id: Optional[int] = 0
-    date_created: Optional[Union[int, float]] = 0
+    date_created: Optional[float] = 0
     application_id: int
     objective_body: Dict[str, str] = Field(default_factory=dict)
 
@@ -16,7 +18,7 @@ class ApplicationObjective(BaseModel):
 class ApplicationAction(BaseModel):
     id: Optional[int] = -1
     action_type: str
-    date_created: Optional[Union[int, float]] = 0
+    date_created: Optional[float] = 0
     application_id: int
     meta: Optional[Config] = None
     last_activity: Optional[int] = 0
@@ -24,11 +26,13 @@ class ApplicationAction(BaseModel):
     prompt: Optional[str] = None
     request_count: Optional[int] = 0
     intent_group_id: Optional[int] = -1
+    agent_id: Optional[int] = None  # New field for agent relationship
+    agent_name: Optional[str] = None  # For joins with agent table
 
 
 class Application(BaseModel):
     id: Optional[int] = -1
-    date_created: Optional[Union[int, float]] = 0
+    date_created: Optional[float] = 0
     application_name: Optional[str] = None
     application_ref_name: Optional[str] = None
     company_id: int = 0
@@ -43,7 +47,7 @@ class Application(BaseModel):
 
 class ApplicationContext(BaseModel):
     id: Optional[int] = -1
-    date_created: Optional[Union[int, float]] = 0
+    date_created: Optional[float] = 0
     application_id: Optional[int] = None
     context_body: Optional[Union[str, Dict[Any, Any]]] = None
     context_path: Optional[str] = None
