@@ -101,6 +101,7 @@ class StreamOptions(BaseModel):
 
 class ToolCallFunction(BaseModel):
     name: Optional[str] = None
+    description: Optional[str] = None
     arguments: str = ""
 
 
@@ -126,7 +127,7 @@ class ToolChoice(BaseModel):
 
 class ChatCompletionParams(BaseModel):
     messages: List[ChatMessage]
-    model: str
+    model: Optional[str] = None
     max_tokens: Optional[int] = None
     response_format: Optional[ResponseFormat] = ResponseFormat(type="text")
     temperature: Optional[float] = None
@@ -217,7 +218,9 @@ class LogProbs(BaseModel):
 
 class ChatCompletionChoice(BaseModel):
     index: Optional[int] = 0
-    message: Optional[ChatCompletionMessage] = None
+    message: ChatCompletionMessage = Field(
+        default_factory=lambda: ChatCompletionMessage(role="assistant", content="")
+    )
     logprobs: Optional[LogProbs] = None
     finish_reason: Optional[str] = ""
     is_correction: bool = False
